==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/ef/ef7b3c1cab97011c27d8b3b775807a2f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticCore/Default/navbar.html.twig */
class __TwigTemplate_a1d00e3b9019b5f7d8ded315a14c017b extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<div class=\"loading-bar\">
    ";
        // line 2
        yield $this->env->getExtension('Symfony\Bridge\Twig\Extension\TranslationExtension')->trans("mautic.core.loading", [], "messages");
        // line 3
        yield "</div>

<div class=\"navbar-nocollapse\">
    <!-- start: left nav -->
    <ul class=\"nav navbar-nav navbar-left\">
        <li class=\"visible-xs\">
            <a href=\"javascript: void(0);\" data-toggle=\"sidebar\" data-direction=\"ltr\">
                <i class=\"ri-menu-line fs-16\"></i>
            </a>
        </li>
        <!-- brand -->
         <li>
            <a class=\"mautic-brand\" href=\"#\">
                <img style=\"border-radius: 0!important;
    width: auto!important;
    height:40px!important;
    margin-left: 20px;
    margin-right: 20px;\t\t
    aspect-ratio: auto!important;\" alt=\"FPÖ\" src=\"/themes/system/CoreBundle/Assets/img/logo__fpoe-kaernten.png\">
                <!--/ logo text -->
            </a>
            <!--/ brand -->
         </li>
        ";
        // line 26
        yield from         $this->loadTemplate("@MauticCore/Helper/button.html.twig", "@MauticCore/Default/navbar.html.twig", 26)->unwrap()->yield(CoreExtension::merge($context, ["buttons" => [["label" => "mautic.core.search_everything", "tooltip_placement" => "right", "variant" => "ghost", "icon" => "ri-search-line ri-xl", "icon_only" => true, "attributes" => ["type" => "button", "data-toggle" => "modal", "data-target" => "#gsearchModal", "class" => "search-button"]]]]));
        // line 43
        yield "
    </ul>
    <!--/ end: left nav -->

    <!-- start: right nav -->
    <ul class=\"nav navbar-nav navbar-right\">
        ";
        // line 49
        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Menu/profile.html.twig");
        yield "
        ";
        // line 50
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\MenuExtension']->menuRender("admin");
        yield "
    </ul>
    <div class=\"navbar-toolbar pull-right mt-15 mr-10\">
    ";
        // line 53
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\ButtonExtension']->reset(Twig\Extension\CoreExtension::constant("Mautic\\CoreBundle\\Twig\\Helper\\ButtonHelper::LOCATION_NAVBAR"));
        yield "
    ";
        // line 54
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\ButtonExtension']->render();
        yield "
    </div>

    <!--/ end: right nav -->
</div>
<!--/ end: navbar nocollapse -->

";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticCore/Default/navbar.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  96 => 54,  92 => 53,  86 => 50,  82 => 49,  74 => 43,  72 => 26,  47 => 3,  45 => 2,  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticCore/Default/navbar.html.twig", "/var/www/mautic-ktn/themes/system/CoreBundle/Resources/views/Default/navbar.html.twig");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/ef/ef7b3c1cab97011c27d8b3b775807a2f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticCore/Default/navbar.html.twig */
class __TwigTemplate_a1d00e3b9019b5f7d8ded315a14c017b extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<div class=\"loading-bar\">
    ";
        // line 2
        yield $this->env->getExtension('Symfony\Bridge\Twig\Extension\TranslationExtension')->trans("mautic.core.loading", [], "messages");
        // line 3
        yield "</div>

<div class=\"navbar-nocollapse\">
    <!-- start: left nav -->
    <ul class=\"nav navbar-nav navbar-left\">
        <li class=\"visible-xs\">
            <a href=\"javascript: void(0);\" data-toggle=\"sidebar\" data-direction=\"ltr\">
                <i class=\"ri-menu-line fs-16\"></i>
            </a>
        </li>
        <!-- brand -->
         <li>
            <a class=\"mautic-brand\" href=\"#\">
                <img style=\"border-radius: 0!important;
    width: auto!important;
    height:40px!important;
    margin-left: 20px;
    margin-right: 20px;\t\t
    aspect-ratio: auto!important;\" alt=\"FPÖ\" src=\"/themes/system/CoreBundle/Assets/img/login_logo.png\">
                <!--/ logo text -->
            </a>
            <!--/ brand -->
         </li>
        ";
        // line 26
        yield from         $this->loadTemplate("@MauticCore/Helper/button.html.twig", "@MauticCore/Default/navbar.html.twig", 26)->unwrap()->yield(CoreExtension::merge($context, ["buttons" => [["label" => "mautic.core.search_everything", "tooltip_placement" => "right", "variant" => "ghost", "icon" => "ri-search-line ri-xl", "icon_only" => true, "attributes" => ["type" => "button", "data-toggle" => "modal", "data-target" => "#gsearchModal", "class" => "search-button"]]]]));
        // line 43
        yield "
    </ul>
    <!--/ end: left nav -->

    <!-- start: right nav -->
    <ul class=\"nav navbar-nav navbar-right\">
        ";
        // line 49
        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Menu/profile.html.twig");
        yield "
        ";
        // line 50
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\MenuExtension']->menuRender("admin");
        yield "
    </ul>
    <div class=\"navbar-toolbar pull-right mt-15 mr-10\">
    ";
        // line 53
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\ButtonExtension']->reset(Twig\Extension\CoreExtension::constant("Mautic\\CoreBundle\\Twig\\Helper\\ButtonHelper::LOCATION_NAVBAR"));
        yield "
    ";
        // line 54
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\ButtonExtension']->render();
        yield "
    </div>

    <!--/ end: right nav -->
</div>
<!--/ end: navbar nocollapse -->

";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticCore/Default/navbar.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  96 => 54,  92 => 53,  86 => 50,  82 => 49,  74 => 43,  72 => 26,  47 => 3,  45 => 2,  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticCore/Default/navbar.html.twig", "/var/www/html/mauticGIT-Test/themes/system/CoreBundle/Resources/views/Default/navbar.html.twig");
    }
}
